@@ -1,5 +1,5 @@
 /* emit.c
-   Copyright (C) 2005,2006,2007 Eugene K. Ressler, Jr.
+   Copyright (C) 2005,2006,2007,2008 Eugene K. Ressler, Jr.
 
 This file is part of Sketch, a small, simple system for making 
 3d drawings with LaTeX and the PSTricks or TikZ package.
@@ -597,7 +597,19 @@ emit_preamble_pst_latex (FILE * f, BOX_3D * ext, GLOBAL_ENV * env)
 	   flt_str (buf2, ext->min[Y]),
 	   flt_str (buf3, ext->max[X]), flt_str (buf4, ext->max[Y]));
 
-  fprintf (f, "\\pstVerb{1 setlinejoin}\n");
+  if (cmp_with_global_pst_version(env, STRINGIFY(PST_LINEJOIN_VERSION), no_line) < 0) 
+    {
+      // old way to set linejoin
+      fprintf (f, "\\pstVerb{1 setlinejoin}\n");
+    }
+  else
+    {
+      fprintf (f, 
+	       "%% If your PSTricks is earlier than Version "
+	       STRINGIFY(PST_LINEJOIN_VERSION) ", it will fail here.\n"
+	       "%% Use sketch -V option for backward compatibility.\n"
+	       "\\psset{linejoin=1}\n");
+    }
 }
 
 void
@@ -618,7 +630,13 @@ emit_preamble_tkz_latex (FILE * f, BOX_3D * ext, GLOBAL_ENV * env)
 	}
     }
 
-  fprintf (f, "\\begin{tikzpicture}[join=round");
+  if (cmp_with_global_tikz_version(env, STRINGIFY(TIKZ_DECORATIONS_VERSION), no_line) >= 0) 
+    {
+      remark (no_line, 
+	      "TikZ warning about deprecated decorations library is okay to ignore");
+    }
+
+  fprintf (f, "\\begin{tikzpicture}[line join=round");
   if (global_env_is_set_p (env, GE_OPTS))
     {
       fprintf (f, ",");
