@@ -1,5 +1,5 @@
 /* geometry.c
-   Copyright (C) 2005,2006,2007 Eugene K. Ressler, Jr.
+   Copyright (C) 2005,2006,2007,2008 Eugene K. Ressler, Jr.
 
 This file is part of Sketch, a small, simple system for making 
 3d drawings with LaTeX and the PSTricks or TikZ package.
@@ -599,15 +599,15 @@ polyline_side_of_plane (POLYLINE_3D * polyline, PLANE * plane)
 void
 init_box_2d (BOX_2D * b)
 {
-  b->min[X] = b->min[Y] = FLT_MAX;
-  b->max[X] = b->max[Y] = -FLT_MAX;
+  b->min[X] = b->min[Y] = FLOAT_MAX;
+  b->max[X] = b->max[Y] = -FLOAT_MAX;
 }
 
 void
 init_box_3d (BOX_3D * b)
 {
-  b->min[X] = b->min[Y] = b->min[Z] = FLT_MAX;
-  b->max[X] = b->max[Y] = b->max[Z] = -FLT_MAX;
+  b->min[X] = b->min[Y] = b->min[Z] = FLOAT_MAX;
+  b->max[X] = b->max[Y] = b->max[Z] = -FLOAT_MAX;
 }
 
 void
