@@ -1,5 +1,5 @@
 /* memutil.c
-   Copyright (C) 2005,2006,2007 Eugene K. Ressler, Jr.
+   Copyright (C) 2005,2006,2007,2008 Eugene K. Ressler, Jr.
 
 This file is part of Sketch, a small, simple system for making 
 3d drawings with LaTeX and the PSTricks or TikZ package.
@@ -63,26 +63,3 @@ safe_free (void *p)
   free (p);
 }
 
-void *
-ref (MEMORY_MANAGED_OBJECT * p)
-{
-  if (p->n_refs < 0)
-    {
-      fprintf (stderr, "ref caught negative ref count\n");
-      exit (1);
-    }
-  ++p->n_refs;
-  return (void *) p;
-}
-
-void
-deref (MEMORY_MANAGED_OBJECT * p)
-{
-  if (p->n_refs <= 0)
-    {
-      fprintf (stderr, "deref caught non-positive ref count\n");
-      exit (1);
-    }
-  if (--p->n_refs == 0)
-    safe_free (p);
-}
