@@ -1,5 +1,5 @@
 /* opts.c
-   Copyright (C) 2005,2006,2007 Eugene K. Ressler, Jr.
+   Copyright (C) 2005,2006,2007,2008 Eugene K. Ressler, Jr.
 
 This file is part of Sketch, a small, simple system for making 
 3d drawings with LaTeX and the PSTricks or TikZ package.
@@ -226,8 +226,10 @@ static OPT_DESC key_tbl_pst[] = {
   {"linecolor", OPT_LINE},
   {"linestyle", OPT_LINE | OPT_LINE_STYLE},
   {"linewidth", OPT_LINE},
+  {"opacity", OPT_POLYGON},
   {"showpoints", OPT_LINE | OPT_POLYGON},
   {"split", OPT_INTERNAL},
+  {"strokeopacity", OPT_LINE },
   {"transpalpha", OPT_POLYGON}
 };
 
