@@ -35,44 +35,43 @@
      DBL_BRACKET_ID = 261,
      CURLY_ID = 262,
      ANGLE_ID = 263,
-     BRACKET_ID_LIST = 264,
-     NUM = 265,
-     OPTS_STR = 266,
-     SPECIAL = 267,
-     TICK = 268,
-     THEN = 269,
-     DEF = 270,
-     EMPTY_ANGLE = 271,
-     DOTS = 272,
-     LINE = 273,
-     CURVE = 274,
-     POLYGON = 275,
-     REPEAT = 276,
-     SWEEP = 277,
-     PUT = 278,
-     TRANSLATE = 279,
-     ROTATE = 280,
-     SCALE = 281,
-     PROJECT = 282,
-     PERSPECTIVE = 283,
-     VIEW = 284,
-     SQRT = 285,
-     SIN = 286,
-     COS = 287,
-     ATAN2 = 288,
-     UNIT = 289,
-     INVERSE = 290,
-     GLOBAL = 291,
-     SET = 292,
-     PICTUREBOX = 293,
-     FRAME = 294,
-     CAMERA = 295,
-     LANGUAGE = 296,
-     PSTRICKS = 297,
-     TIKZ = 298,
-     LaTeX = 299,
-     ConTeXt = 300,
-     NEG = 301
+     NUM = 264,
+     OPTS_STR = 265,
+     SPECIAL = 266,
+     TICK = 267,
+     THEN = 268,
+     DEF = 269,
+     EMPTY_ANGLE = 270,
+     DOTS = 271,
+     LINE = 272,
+     CURVE = 273,
+     POLYGON = 274,
+     REPEAT = 275,
+     SWEEP = 276,
+     PUT = 277,
+     TRANSLATE = 278,
+     ROTATE = 279,
+     SCALE = 280,
+     PROJECT = 281,
+     PERSPECTIVE = 282,
+     VIEW = 283,
+     SQRT = 284,
+     SIN = 285,
+     COS = 286,
+     ATAN2 = 287,
+     UNIT = 288,
+     INVERSE = 289,
+     GLOBAL = 290,
+     SET = 291,
+     PICTUREBOX = 292,
+     FRAME = 293,
+     CAMERA = 294,
+     LANGUAGE = 295,
+     PSTRICKS = 296,
+     TIKZ = 297,
+     LaTeX = 298,
+     ConTeXt = 299,
+     NEG = 300
    };
 #endif
 /* Tokens.  */
@@ -82,44 +81,43 @@
 #define DBL_BRACKET_ID 261
 #define CURLY_ID 262
 #define ANGLE_ID 263
-#define BRACKET_ID_LIST 264
-#define NUM 265
-#define OPTS_STR 266
-#define SPECIAL 267
-#define TICK 268
-#define THEN 269
-#define DEF 270
-#define EMPTY_ANGLE 271
-#define DOTS 272
-#define LINE 273
-#define CURVE 274
-#define POLYGON 275
-#define REPEAT 276
-#define SWEEP 277
-#define PUT 278
-#define TRANSLATE 279
-#define ROTATE 280
-#define SCALE 281
-#define PROJECT 282
-#define PERSPECTIVE 283
-#define VIEW 284
-#define SQRT 285
-#define SIN 286
-#define COS 287
-#define ATAN2 288
-#define UNIT 289
-#define INVERSE 290
-#define GLOBAL 291
-#define SET 292
-#define PICTUREBOX 293
-#define FRAME 294
-#define CAMERA 295
-#define LANGUAGE 296
-#define PSTRICKS 297
-#define TIKZ 298
-#define LaTeX 299
-#define ConTeXt 300
-#define NEG 301
+#define NUM 264
+#define OPTS_STR 265
+#define SPECIAL 266
+#define TICK 267
+#define THEN 268
+#define DEF 269
+#define EMPTY_ANGLE 270
+#define DOTS 271
+#define LINE 272
+#define CURVE 273
+#define POLYGON 274
+#define REPEAT 275
+#define SWEEP 276
+#define PUT 277
+#define TRANSLATE 278
+#define ROTATE 279
+#define SCALE 280
+#define PROJECT 281
+#define PERSPECTIVE 282
+#define VIEW 283
+#define SQRT 284
+#define SIN 285
+#define COS 286
+#define ATAN2 287
+#define UNIT 288
+#define INVERSE 289
+#define GLOBAL 290
+#define SET 291
+#define PICTUREBOX 292
+#define FRAME 293
+#define CAMERA 294
+#define LANGUAGE 295
+#define PSTRICKS 296
+#define TIKZ 297
+#define LaTeX 298
+#define ConTeXt 299
+#define NEG 300
 
 
 
@@ -134,14 +132,13 @@ typedef union YYSTYPE {
   TRANSFORM xf;
   EXPR_VAL exv;
   SYMBOL_NAME name;
-  SYMBOL_NAME_NODE *name_list;
   OBJECT *obj;
   OPTS *opts;
   int bool;
   int index;
 } YYSTYPE;
 /* Line 1447 of yacc.c.  */
-#line 145 "y.tab.h"
+#line 142 "y.tab.h"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
